@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 12093 2020-04-19 14:34:56Z Trista $
+# $Id: Util.py 12110 2020-04-23 13:27:25Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $ (last)
-# $Date: 2020-04-19 23:34:56 +0900 (週日, 19 四月 2020) $
-# $Revision: 12093 $
+# $Date: 2020-04-23 21:27:25 +0800 (週四, 23 四月 2020) $
+# $Revision: 12110 $
 """
 Utilities.
 """
@@ -29,8 +29,21 @@ def update(settingsDict, defaults, config=None):
     for k, v in list(defaults.items()):
         if k not in settingsDict:
             settingsDict[k] = v
+            
+def determinePrintDetail(printDetail, args)
+    if len(args) >= 2:
+        if (args[0].endswith('manage.py')) and (args[1] == 'runserver'):
+            printDetail = printDetail
+        else:
+            printDetail = False
+            
+    # if the command is not manage.py runserver(ex: cms_dumpdata), do NOT print SERVER_MODE
+    else:
+        printDetail = False
+    
+    return PrintDetail
 
-def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None):
+def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None, PrintDetail=True):
     """
     Populate value in environment variables to settings.
 
@@ -47,17 +60,10 @@ def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None):
     from Iuppiter.Util import colored
     
     args = sys.argv
+    printDetail = determinePrintDetail(printDetail, args)
 
     # if the command is manage.py runserver, then print the SERVER_MODE
-    if len(args) >= 2:
-        if (args[0].endswith('manage.py')) and (args[1] == 'runserver'):
-            printDetail = True
-        else:
-            printDetail = False
-            
-    # if the command is not manage.py runserver(ex: cms_dumpdata), do NOT print SERVER_MODE
-    else:
-        printDetail = False
+    
     
     for k in keys:
         if k in os.environ:
